@@ -1,6 +1,6 @@
 /*****************************************************************************
  * Copyright (C) 2009 Csaba Karai <krusader@users.sourceforge.net>           *
- * Copyright (C) 2009-2018 Krusader Krew [https://krusader.org]              *
+ * Copyright (C) 2009-2019 Krusader Krew [https://krusader.org]              *
  *                                                                           *
  * This file is part of Krusader [https://krusader.org].                     *
  *                                                                           *
@@ -485,7 +485,7 @@ void countFiles(const QString &path, unsigned long &totalFiles, bool &stop)
 {
     const QDir dir(path);
     if (!dir.exists()) {
-        totalFiles++; // assume its a file
+        totalFiles++; // assume it's a file
         return;
     }
 
