@@ -1,7 +1,7 @@
 /*****************************************************************************
  * Copyright (C) 2001 Shie Erlich <krusader@users.sourceforge.net>           *
  * Copyright (C) 2001 Rafi Yanai <krusader@users.sourceforge.net>            *
- * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ * Copyright (C) 2004-2019 Krusader Krew [https://krusader.org]              *
  *                                                                           *
  * This file is part of Krusader [https://krusader.org].                     *
  *                                                                           *
@@ -74,7 +74,7 @@ public:
     // queries the password from the user
     static QString getPassword(QString path);
     // detects the archive type
-    void checkIf7zIsEncrypted(bool &, QString);
+    void checkIf7zIsEncrypted(bool &, QString) Q_DECL_OVERRIDE;
 private:
     //! checks if a returned status ("exit code") of an archiving-related process is OK
     static bool checkStatus(QString type, int exitCode);
