@@ -1,7 +1,7 @@
 /*****************************************************************************
  * Copyright (C) 2000 Shie Erlich <krusader@users.sourceforge.net>           *
  * Copyright (C) 2000 Rafi Yanai <krusader@users.sourceforge.net>            *
- * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ * Copyright (C) 2004-2019 Krusader Krew [https://krusader.org]              *
  *                                                                           *
  * This file is part of Krusader [https://krusader.org].                     *
  *                                                                           *
@@ -61,7 +61,7 @@ public:
     QUrl getUrl(const QString &name) const Q_DECL_OVERRIDE;
     bool canMoveToTrash(const QStringList &) const Q_DECL_OVERRIDE { return isLocal(); }
 
-    QString mountPoint() const { return _mountPoint; }
+    QString mountPoint() const Q_DECL_OVERRIDE { return _mountPoint; }
     bool hasAutoUpdate() const Q_DECL_OVERRIDE { return !_watcher.isNull(); }
     void updateFilesystemInfo() Q_DECL_OVERRIDE;
 
