@@ -1,6 +1,6 @@
 /*****************************************************************************
  * Copyright (C) 2000 Rafi Yanai <krusader@users.sourceforge.net>            *
- * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ * Copyright (C) 2004-2019 Krusader Krew [https://krusader.org]              *
  *                                                                           *
  * This file is part of Krusader [https://krusader.org].                     *
  *                                                                           *
@@ -30,6 +30,7 @@
 
 #include "krpermhandler.h"
 #include "filesystemprovider.h"
+#include "../compat.h"
 
 bool FileItem::userDefinedFolderIcons = true;
 
@@ -46,13 +47,13 @@ static QCache<const QUrl, FileSize> s_fileSizeCache(1000);
 
 FileItem::FileItem(const QString &name, const QUrl &url, bool isDir,
              KIO::filesize_t size, mode_t mode,
-             time_t mtime, time_t ctime, time_t atime,
+             time_t mtime, time_t ctime, time_t atime, time_t btime,
              uid_t uid, gid_t gid, const QString &owner, const QString &group,
              bool isLink, const QString &linkDest, bool isBrokenLink,
              const QString &acl, const QString &defaultAcl)
     : m_name(name), m_url(url), m_isDir(isDir),
       m_size(size), m_mode(mode),
-      m_mtime(mtime), m_ctime(ctime), m_atime(atime),
+      m_mtime(mtime), m_ctime(ctime), m_atime(atime), m_btime(btime),
       m_uid(uid), m_gid(gid), m_owner(owner), m_group(group),
       m_isLink(isLink), m_linkDest(linkDest), m_isBrokenLink(isBrokenLink),
       m_acl(acl), m_defaulfAcl(defaultAcl), m_AclLoaded(false),
@@ -75,7 +76,7 @@ FileItem *FileItem::createDummy()
 {
     FileItem *file = new FileItem("..", QUrl(), true,
                             0, 0,
-                            0, 0, 0);
+                            -1, -1, -1, -1);
     file->setIconName("go-up");
     return file;
 }
@@ -83,7 +84,8 @@ FileItem *FileItem::createDummy()
 FileItem *FileItem::createBroken(const QString &name, const QUrl &url)
 {
     FileItem *file = new FileItem(name, url, false,
-                                  0, 0, 0, 0, 0);
+                                  0, 0,
+                                  -1, -1, -1, -1);
     file->setIconName("file-broken");
     return file;
 }
@@ -92,7 +94,7 @@ FileItem *FileItem::createVirtualDir(const QString &name, const QUrl &url)
 {
     return new FileItem(name, url, true,
                      0, 0700,
-                     time(0), time(0), time(0),
+                     -1, -1, -1, -1,
                      getuid(), getgid());
 }
 
@@ -100,7 +102,7 @@ FileItem *FileItem::createCopy(const FileItem &file, const QString &newName)
 {
     return new FileItem(newName, file.getUrl(), file.isDir(),
                      file.getSize(), file.getMode(),
-                     file.getTime_t(), file.getChangedTime(), file.getAccessTime(),
+                     file.getModificationTime(), file.getChangeTime(), file.getAccessTime(), file.getCreationTime(),
                      file.m_uid, file.m_gid, file.getOwner(), file.getGroup(),
                      file.isSymLink(), file.getSymDest(), file.isBrokenLink());
 }
@@ -200,30 +202,32 @@ const KIO::UDSEntry FileItem::getEntry()
 {
     KIO::UDSEntry entry;
 
-    entry.insert(KIO::UDSEntry::UDS_NAME, getName());
-    entry.insert(KIO::UDSEntry::UDS_SIZE, getSize());
-    entry.insert(KIO::UDSEntry::UDS_MODIFICATION_TIME, getTime_t());
-    entry.insert(KIO::UDSEntry::UDS_CREATION_TIME, getChangedTime());
-    entry.insert(KIO::UDSEntry::UDS_ACCESS_TIME, getAccessTime());
-    entry.insert(KIO::UDSEntry::UDS_USER, getOwner());
-    entry.insert(KIO::UDSEntry::UDS_GROUP, getGroup());
-    entry.insert(KIO::UDSEntry::UDS_MIME_TYPE, getMime());
-    entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, getMode() & S_IFMT);
-    entry.insert(KIO::UDSEntry::UDS_ACCESS, getMode() & 07777);
+    entry.UDS_ENTRY_INSERT(KIO::UDSEntry::UDS_NAME, getName());
+    entry.UDS_ENTRY_INSERT(KIO::UDSEntry::UDS_SIZE, getSize());
+    entry.UDS_ENTRY_INSERT(KIO::UDSEntry::UDS_MODIFICATION_TIME, getModificationTime());
+    if (m_btime != -1) {
+        entry.UDS_ENTRY_INSERT(KIO::UDSEntry::UDS_CREATION_TIME, getCreationTime());
+    }
+    entry.UDS_ENTRY_INSERT(KIO::UDSEntry::UDS_ACCESS_TIME, getAccessTime());
+    entry.UDS_ENTRY_INSERT(KIO::UDSEntry::UDS_USER, getOwner());
+    entry.UDS_ENTRY_INSERT(KIO::UDSEntry::UDS_GROUP, getGroup());
+    entry.UDS_ENTRY_INSERT(KIO::UDSEntry::UDS_MIME_TYPE, getMime());
+    entry.UDS_ENTRY_INSERT(KIO::UDSEntry::UDS_FILE_TYPE, getMode() & S_IFMT);
+    entry.UDS_ENTRY_INSERT(KIO::UDSEntry::UDS_ACCESS, getMode() & 07777);
 
     if (isSymLink())
-        entry.insert(KIO::UDSEntry::UDS_LINK_DEST, getSymDest());
+        entry.UDS_ENTRY_INSERT(KIO::UDSEntry::UDS_LINK_DEST, getSymDest());
 
     if (!m_AclLoaded)
         loadACL();
     if (!m_acl.isNull() || !m_defaulfAcl.isNull()) {
-        entry.insert(KIO::UDSEntry::UDS_EXTENDED_ACL, 1);
+        entry.UDS_ENTRY_INSERT(KIO::UDSEntry::UDS_EXTENDED_ACL, 1);
 
         if (!m_acl.isNull())
-            entry.insert(KIO::UDSEntry::UDS_ACL_STRING, m_acl);
+            entry.UDS_ENTRY_INSERT(KIO::UDSEntry::UDS_ACL_STRING, m_acl);
 
         if (!m_defaulfAcl.isNull())
-            entry.insert(KIO::UDSEntry::UDS_DEFAULT_ACL_STRING, m_defaulfAcl);
+            entry.UDS_ENTRY_INSERT(KIO::UDSEntry::UDS_DEFAULT_ACL_STRING, m_defaulfAcl);
     }
 
     return entry;
