@@ -1,7 +1,7 @@
 /*****************************************************************************
  * Copyright (C) 2000 Shie Erlich <krusader@users.sourceforge.net>           *
  * Copyright (C) 2000 Rafi Yanai <krusader@users.sourceforge.net>            *
- * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ * Copyright (C) 2004-2019 Krusader Krew [https://krusader.org]              *
  *                                                                           *
  * This file is part of Krusader [https://krusader.org].                     *
  *                                                                           *
@@ -56,8 +56,9 @@ public:
      * @param size size of file
      * @param mode mode of file (file type and permissions)
      * @param mtime file modification time
-     * @param ctime file changed time
+     * @param ctime file change time. Use -1 if unknown.
      * @param atime file access time
+     * @param btime file creation time. Use -1 if unknown.
      * @param uid Unix user id of file owner. Use -1 here and provide an owner name for non-local files.
      * @param gid Unix group id of file group. Use -1 here and provide a group name for non-local files.
      * @param owner user name of file owner. Can be empty for local files
@@ -70,7 +71,7 @@ public:
      */
     FileItem(const QString &name, const QUrl &url, bool isDir,
           KIO::filesize_t size, mode_t mode,
-          time_t mtime, time_t ctime, time_t atime,
+          time_t mtime, time_t ctime, time_t atime, time_t btime,
           uid_t uid = -1, gid_t gid = -1,
           const QString &owner = QString(), const QString &group = QString(),
           bool isLink = false, const QString &linkDest = QString(), bool isBrokenLink = false,
@@ -97,9 +98,14 @@ public:
     inline bool isBrokenLink() const { return m_isBrokenLink; }
     inline const QString &getSymDest() const { return m_linkDest; }
     inline mode_t getMode() const { return m_mode; }
-    inline time_t getTime_t() const { return m_mtime; }
-    inline time_t getChangedTime() const { return m_ctime; }
+    /** Return the file modification time (mtime) or -1 if unknown. */
+    inline time_t getModificationTime() const { return m_mtime; }
+    /** Return the file change time (ctime) or -1 if unknown. */
+    inline time_t getChangeTime() const { return m_ctime; }
+    /** Return the file access time (atime) or -1 if unknown. */
     inline time_t getAccessTime() const { return m_atime; }
+    /** Return the file creation time (btime) or -1 if unknown. */
+    inline time_t getCreationTime() const { return m_btime; }
     inline const QUrl &getUrl() const { return m_url; }
     inline const QString &getOwner() const { return m_owner; }
     inline const QString &getGroup() const { return m_group; }
@@ -136,8 +142,9 @@ private:
     mode_t m_mode;              //< file mode (file type and permissions)
 
     time_t m_mtime;             //< file modification time
-    time_t m_ctime;             //< file changed time
+    time_t m_ctime;             //< file change time
     time_t m_atime;             //< file access time
+    time_t m_btime;             //< file creation time
 
     uid_t m_uid;                //< file owner id
     gid_t m_gid;                //< file group id
