@@ -1,7 +1,7 @@
 /*****************************************************************************
  * Copyright (C) 2001 Shie Erlich <krusader@users.sourceforge.net>           *
  * Copyright (C) 2001 Rafi Yanai <krusader@users.sourceforge.net>            *
- * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ * Copyright (C) 2004-2019 Krusader Krew [https://krusader.org]              *
  *                                                                           *
  * This file is part of Krusader [https://krusader.org].                     *
  *                                                                           *
@@ -307,7 +307,7 @@ bool KRQuery::match(FileItem *item) const
     if (maxSize && size > maxSize)
         return false;
     // check the time frame
-    time_t mtime = item->getTime_t();
+    time_t mtime = item->getModificationTime();
     if (olderThen && mtime > olderThen)
         return false;
     if (newerThen && mtime < newerThen)
