@@ -1,6 +1,6 @@
 /*****************************************************************************
  * Copyright (C) 2004 Csaba Karai <krusader@users.sourceforge.net>           *
- * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ * Copyright (C) 2004-2019 Krusader Krew [https://krusader.org]              *
  *                                                                           *
  * This file is part of Krusader [https://krusader.org].                     *
  *                                                                           *
@@ -84,7 +84,7 @@ public:
         setAlternatingRowColors(true);
     }
 
-    void startDrag(Qt::DropActions supportedActs) {
+    void startDrag(Qt::DropActions supportedActs) Q_DECL_OVERRIDE {
         Q_UNUSED(supportedActs);
 
         QList<QUrl> urls;
@@ -114,7 +114,7 @@ public:
 KProcess *  LocateDlg::updateProcess = 0;
 LocateDlg * LocateDlg::LocateDialog = 0;
 
-LocateDlg::LocateDlg() : QDialog(0), isFeedToListBox(false)
+LocateDlg::LocateDlg(QWidget *parent) : QDialog(parent), isFeedToListBox(false)
 {
     setWindowTitle(i18n("Krusader::Locate"));
     setWindowModality(Qt::NonModal);
