@@ -1,6 +1,6 @@
 /*****************************************************************************
  * Copyright (C) 2004 Csaba Karai <krusader@users.sourceforge.net>           *
- * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ * Copyright (C) 2004-2019 Krusader Krew [https://krusader.org]              *
  *                                                                           *
  * This file is part of Krusader [https://krusader.org].                     *
  *                                                                           *
@@ -39,7 +39,7 @@ class LocateDlg : public QDialog
     Q_OBJECT
 
 public:
-    LocateDlg();
+    explicit LocateDlg(QWidget *parent);
 
     static LocateDlg *LocateDialog;
 
