@@ -1,7 +1,7 @@
 /*****************************************************************************
  * Copyright (C) 2000-2002 Shie Erlich <krusader@users.sourceforge.net>      *
  * Copyright (C) 2000-2002 Rafi Yanai <krusader@users.sourceforge.net>       *
- * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ * Copyright (C) 2004-2019 Krusader Krew [https://krusader.org]              *
  *                                                                           *
  * This file is part of Krusader [https://krusader.org].                     *
  *                                                                           *
@@ -398,19 +398,24 @@ void KrView::getSelectedItems(QStringList *names, bool fallbackToFocused)
     }
 }
 
-void KrView::getSelectedKrViewItems(KrViewItemList *items)
+KrViewItemList KrView::getSelectedKrViewItems()
 {
-    for (KrViewItem * it = getFirst(); it != 0; it = getNext(it))
-        if (it->isSelected() && (it->name() != "..")) items->append(it);
+    KrViewItemList items;
+    for (KrViewItem * it = getFirst(); it != nullptr; it = getNext(it)) {
+        if (it->isSelected() && (it->name() != "..")) {
+            items.append(it);
+        }
+    }
 
     // if all else fails, take the current item
-    QString item = getCurrentItem();
-    if (items->empty() &&
-            !item.isEmpty() &&
-            item != ".." &&
-            getCurrentKrViewItem() != 0) {
-        items->append(getCurrentKrViewItem());
+    if (items.empty()) {
+        KrViewItem *currentItem = getCurrentKrViewItem();
+        if (currentItem && !currentItem->isDummy()) {
+            items.append(getCurrentKrViewItem());
+        }
     }
+
+    return items;
 }
 
 QString KrView::statistics()
@@ -476,8 +481,7 @@ bool KrView::changeSelection(const KRQuery& filter, bool select, bool includeDir
         makeItemVisible(temp);
     } else if (makeVisible && firstMatch != 0) {
         // if no selected item is visible...
-        KrViewItemList selectedItems;
-        getSelectedKrViewItems(&selectedItems);
+        const KrViewItemList selectedItems = getSelectedKrViewItems();
         bool anyVisible = false;
         for (KrViewItem *item : selectedItems) {
             if (isItemVisible(item)) {
