@@ -1,7 +1,7 @@
 /*****************************************************************************
  * Copyright (C) 2002 Shie Erlich <erlich@users.sourceforge.net>             *
  * Copyright (C) 2002 Rafi Yanai <yanai@users.sourceforge.net>               *
- * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ * Copyright (C) 2004-2019 Krusader Krew [https://krusader.org]              *
  *                                                                           *
  * This file is part of Krusader [https://krusader.org].                     *
  *                                                                           *
@@ -153,10 +153,10 @@ QVariant ListModel::data(const QModelIndex& index, int role) const
             return mimeType.isEmpty() ? QVariant() : mimeType;
         }
         case KrViewProperties::Modified: {
-            return fileitem == _dummyFileItem ? QVariant() : dateText(fileitem->getTime_t());
+            return fileitem == _dummyFileItem ? QVariant() : dateText(fileitem->getModificationTime());
         }
         case KrViewProperties::Changed: {
-            return fileitem == _dummyFileItem ? QVariant() : dateText(fileitem->getChangedTime());
+            return fileitem == _dummyFileItem ? QVariant() : dateText(fileitem->getChangeTime());
         }
         case KrViewProperties::Accessed: {
             return fileitem == _dummyFileItem ? QVariant() : dateText(fileitem->getAccessTime());
@@ -359,31 +359,20 @@ void ListModel::removeItem(FileItem *fileItem)
     if (rowToRemove < 0)
         return;
 
-    emit layoutAboutToBeChanged();
+    beginRemoveRows(QModelIndex(), rowToRemove, rowToRemove);
 
     _fileItems.removeAt(rowToRemove);
 
     _fileItemNdx.remove(fileItem);
     _nameNdx.remove(fileItem->getName());
     _urlNdx.remove(fileItem->getUrl());
-    // update indices for fileItems following fileitem
+
+    // update indices for fileItems following the removed fileitem
     for (int i = rowToRemove; i < _fileItems.count(); i++) {
         updateIndices(_fileItems[i], i);
     }
 
-    const QModelIndexList oldPersistentList = persistentIndexList();
-    QModelIndexList newPersistentList;
-    foreach (const QModelIndex &mndx, oldPersistentList) {
-        int newRow = mndx.row();
-        if (newRow > rowToRemove)
-            newRow--;
-        if (newRow != rowToRemove)
-            newPersistentList << index(newRow, mndx.column());
-        else
-            newPersistentList << QModelIndex();
-    }
-    changePersistentIndexList(oldPersistentList, newPersistentList);
-    emit layoutChanged();
+    endRemoveRows();
 }
 
 QVariant ListModel::headerData(int section, Qt::Orientation orientation, int role) const
@@ -509,8 +498,8 @@ QString ListModel::toolTipText(FileItem *fileItem) const
         text += i18n("Size: %1", size) + "<br>";
     }
     text += i18nc("File property", "Type: %1", KrView::mimeTypeText(fileItem));
-    text += "<br>" + i18nc("File property", "Modified: %1", dateText(fileItem->getTime_t()));
-    text += "<br>" + i18nc("File property", "Changed: %1", dateText(fileItem->getChangedTime()));
+    text += "<br>" + i18nc("File property", "Modified: %1", dateText(fileItem->getModificationTime()));
+    text += "<br>" + i18nc("File property", "Changed: %1", dateText(fileItem->getChangeTime()));
     text += "<br>" + i18nc("File property", "Last Access: %1", dateText(fileItem->getAccessTime()));
     text += "<br>" + i18nc("File property", "Permissions: %1",
             KrView::permissionsText(properties(), fileItem));
@@ -529,6 +518,10 @@ QString ListModel::toolTipText(FileItem *fileItem) const
 
 QString ListModel::dateText(time_t time)
 {
+    if (time == -1) {
+        // unknown time
+        return QString();
+    }
     struct tm* t = localtime((time_t *) & time);
 
     const QDateTime dateTime(QDate(t->tm_year + 1900, t->tm_mon + 1, t->tm_mday),
