@@ -1,7 +1,7 @@
 /*****************************************************************************
  * Copyright (C) 2000 Shie Erlich <krusader@users.sourceforge.net>           *
  * Copyright (C) 2000 Rafi Yanai <krusader@users.sourceforge.net>            *
- * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ * Copyright (C) 2004-2019 Krusader Krew [https://krusader.org]              *
  *                                                                           *
  * This file is part of Krusader [https://krusader.org].                     *
  *                                                                           *
@@ -668,7 +668,7 @@ void ListPanel::compareDirs(bool otherPanelToo)
         if (otherItem) {
             if (!func->getFileItem(item)->isDir())
                 isDifferent = otherPanel()->func->getFileItem(otherItem)->getSize() != func->getFileItem(item)->getSize();
-            isNewer = func->getFileItem(item)->getTime_t() > otherPanel()->func->getFileItem(otherItem)->getTime_t();
+            isNewer = func->getFileItem(item)->getModificationTime() > otherPanel()->func->getFileItem(otherItem)->getModificationTime();
         }
 
         switch (compareMode) {
@@ -881,13 +881,10 @@ void ListPanel::popEmptyRightClickMenu(const QPoint &loc)
     PanelContextMenu::run(loc, this);
 }
 
-QString ListPanel::getCurrentName()
+QString ListPanel::getCurrentName() const
 {
-    QString name = view->getCurrentItem();
-    if (name != "..")
-        return name;
-    else
-        return QString();
+    const QString name = view->getCurrentItem();
+    return name == ".." ? QString() : name;
 }
 
 QStringList ListPanel::getSelectedNames()
