@@ -1,7 +1,7 @@
 /*****************************************************************************
  * Copyright (C) 2000 Shie Erlich <krusader@users.sourceforge.net>           *
  * Copyright (C) 2000 Rafi Yanai <krusader@users.sourceforge.net>            *
- * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ * Copyright (C) 2004-2019 Krusader Krew [https://krusader.org]              *
  *                                                                           *
  * This file is part of Krusader [https://krusader.org].                     *
  *                                                                           *
@@ -113,7 +113,7 @@ public:
         return _actions;
     }
     QString lastLocalPath() const;
-    QString getCurrentName();
+    QString getCurrentName() const;
     QStringList getSelectedNames();
     void setButtons();
     void setJumpBack(QUrl url);
