@@ -1,6 +1,6 @@
 /*****************************************************************************
  * Copyright (C) 2003 Csaba Karai <krusader@users.sourceforge.net>           *
- * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ * Copyright (C) 2004-2019 Krusader Krew [https://krusader.org]              *
  *                                                                           *
  * This file is part of Krusader [https://krusader.org].                     *
  *                                                                           *
@@ -150,7 +150,7 @@ public slots:
     void saveToProfile(QString);
 
 protected slots:
-    void reject();
+    void reject() Q_DECL_OVERRIDE;
     void addFile(SynchronizerFileItem *);
     void markChanged(SynchronizerFileItem *, bool);
     void setScrolling(bool);
@@ -179,7 +179,6 @@ private:
 
 protected:
     virtual void keyPressEvent(QKeyEvent *) Q_DECL_OVERRIDE;
-    virtual void resizeEvent(QResizeEvent *e) Q_DECL_OVERRIDE;
     virtual bool eventFilter(QObject *, QEvent *) Q_DECL_OVERRIDE;
 
     void executeOperation(SynchronizerFileItem *item, int op);
@@ -238,13 +237,9 @@ private:
     bool           isComparing;
     bool           wasClosed;
     bool           wasSync;
-    bool           firstResize;
     bool           hasSelectedFiles;
     SyncViewItem  *lastItem;
 
-    int            sizeX;
-    int            sizeY;
-
     QColor         foreGrounds[ TT_MAX ];
     QColor         backGrounds[ TT_MAX ];
 };
