@@ -1,7 +1,7 @@
 /*****************************************************************************
  * Copyright (C) 2004 Jonas Bähr <jonas.baehr@web.de>                        *
  * Copyright (C) 2004 Shie Erlich <erlich@users.sourceforge.net>             *
- * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ * Copyright (C) 2004-2019 Krusader Krew [https://krusader.org]              *
  *                                                                           *
  * This file is part of Krusader [https://krusader.org].                     *
  *                                                                           *
@@ -114,7 +114,7 @@ namespace
 class exp_simpleplaceholder : public exp_placeholder
 {
 public:
-    EXP_FUNC;
+    EXP_FUNC Q_DECL_OVERRIDE;
     virtual TagString expFunc(const KrPanel*, const QStringList&, const bool&, Expander&) const = 0;
 };
 
@@ -123,7 +123,7 @@ public:
     class name : public exp_placeholder { \
     public: \
         name(); \
-        virtual TagString expFunc ( const KrPanel*, const TagStringList&, const bool&, Expander& ) const; \
+        virtual TagString expFunc ( const KrPanel*, const TagStringList&, const bool&, Expander& ) const Q_DECL_OVERRIDE; \
     };
 
 #define SIMPLE_PLACEHOLDER_CLASS(name) \
@@ -131,7 +131,7 @@ public:
     public: \
         using exp_simpleplaceholder::expFunc; \
         name(); \
-        virtual TagString expFunc ( const KrPanel*, const QStringList&, const bool&, Expander& ) const; \
+        virtual TagString expFunc ( const KrPanel*, const QStringList&, const bool&, Expander& ) const Q_DECL_OVERRIDE; \
     };
 
 
