@@ -1,7 +1,7 @@
 /*****************************************************************************
  * Copyright (C) 2001 Shie Erlich <krusader@users.sourceforge.net>           *
  * Copyright (C) 2001 Rafi Yanai <krusader@users.sourceforge.net>            *
- * Copyright (C) 2004-2018 Krusader Krew [https://krusader.org]              *
+ * Copyright (C) 2004-2019 Krusader Krew [https://krusader.org]              *
  *                                                                           *
  * This file is part of Krusader [https://krusader.org].                     *
  *                                                                           *
@@ -390,13 +390,13 @@ void KRslots::locate()
         return;
     }
 
-    if (LocateDlg::LocateDialog != 0) {
+    if (LocateDlg::LocateDialog != nullptr) {
         LocateDlg::LocateDialog->showNormal();
         LocateDlg::LocateDialog->raise();
         LocateDlg::LocateDialog->activateWindow();
         LocateDlg::LocateDialog->reset();
     } else
-        LocateDlg::LocateDialog = new LocateDlg();
+        LocateDlg::LocateDialog = new LocateDlg(krApp);
 }
 
 void KRslots::runTerminal(const QString & dir)
